Summary: A shared library that implements a Lisp dialect.
Name: librep
Version: 0.91.1
Release: 1
Epoch: 2
License: GPL
Group: Development/Languages
Source: http://prdownloads.sourceforge.net/librep/librep-%{version}.tar.bz2
# Patch1: librep-0.16.1-no_rpath.patch
# Patch2: librep-lc-messages.diff
URL: http://librep.sourceforge.net/
Buildroot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: gmp-devel
BuildRequires: gdbm-devel
BuildRequires: autoconf
BuildRequires: gcc-c++
BuildRequires: texinfo
BuildRequires: libffi-devel
BuildRequires: readline-devel
Requires: gmp >= 4.0.1-3
Packager: Jan "Yenya" Kasprzak, http://www.fi.muni.cz/~kas/

%description
The librep shared library implements a Lisp dialect that is
lightweight, reasonably fast, and extensible. It contains an
interpreter, byte-code compiler, and virtual machine. Applications may
use the interpreter as an extension language, or it may be used for
standalone scripts. The Lisp dialect was originally inspired by Emacs
Lisp. Unlike Emacs Lisp, the reliance on dynamic scope has been
removed and librep only has a single namespace for symbols.

%package devel
Summary: Include files and link libraries for librep development.
Group: Development/Languages
Requires: librep = %{epoch}:%{version}

%description devel
The link libraries and C header files for librep development. Librep
is an embeddable dialect of Lisp.

%prep
%setup
# %patch1 -p1 -b .no_rpath

%build
libtoolize --force --copy
./autogen.sh --build=%{_target_platform} --host=%{_target_platform}
%configure --build=%{_target_platform} --host=%{_target_platform} \
%ifarch ia64
	--with-malloc-alignment=8 \
%endif	
        --with-readline --enable-shared --enable-static

make host_type=%{_target_platform}

%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT host_type=%{_target_platform} install
gzip -9nf $RPM_BUILD_ROOT%{_infodir}/librep*

# Remove files from buildroot that we are not going to package
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_infodir}/dir

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc NEWS README TODO
%{_bindir}/rep
%{_bindir}/rep-remote
%{_libdir}/*.so.*
%{_datadir}/rep
# %{_libexecdir}/rep

%files devel
%defattr(-,root,root)
%{_bindir}/rep-xgettext
%{_bindir}/repdoc
%{_libdir}/*.a
%{_libdir}/*.so
%{_libdir}/pkgconfig/librep.pc
%{_libdir}/rep
%{_includedir}/rep
## with automake 1.5 this may not be found, because configure uses aclocal --print-ac-dir
## %{_datadir}/aclocal/*
%{_datadir}/emacs/site-lisp/*
%{_datadir}/info/*.info*
%doc %{_mandir}/man1/*

%post -p /sbin/ldconfig

%post devel
/sbin/install-info %{_infodir}/librep.info.gz %{_infodir}/dir

%postun -p /sbin/ldconfig

%preun devel
if [ $1 = 0 ]; then
	/sbin/install-info --delete %{_infodir}/librep.info.gz %{_infodir}/dir
fi

%changelog
* Tue Mar 22 2011 Jan "Yenya" Kasprzak <kas@fi.muni.cz> 0.91.1
- updated, rebuilt for F14

* Fri Jul 30 2010 Jan "Yenya" Kasprzak <kas@fi.muni.cz> 0.90.6-1
- updated, rebuilt for F13

* Mon Jun 17 2005 darkness <darkness@codefu.org>
- Updated to librep 0.17, rebuilt for FC4.

* Tue Mar 02 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Tue Dec  2 2003 Thomas Woerner <twoerner@redhat.com> 1:0.16.1-4
- removed rpath from rep-config

* Wed Jun 04 2003 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Tue Jun  3 2003 Jeff Johnson <jbj@redhat.com>
- add explicit epoch's where needed.

* Wed Jan 22 2003 Tim Powers <timp@redhat.com>
- rebuilt

* Thu Dec 12 2002 Havoc Pennington <hp@redhat.com>
- 0.16.1

* Mon Nov 25 2002 Mike A. Harris <mharris@redhat.com> 0.16-4
- s/Copyright/License
- Put _tmppath in Buildroot tag
- Remove unpackaged files in %%install

* Thu Aug 15 2002 Havoc Pennington <hp@redhat.com>
- do the install-info stuff in -devel post/preun, not base package

* Tue Aug 13 2002 Havoc Pennington <hp@redhat.com>
- don't own files in both -devel and regular, #71133

* Sat Jul 27 2002 Havoc Pennington <hp@redhat.com>
- change CVS snap to 0.16 version

* Fri Jun 21 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Wed Jun 19 2002 Havoc Pennington <hp@redhat.com>
- don't own some funky /usr/share/info/dir file that the build system
  is somehow creating

* Wed Jun 19 2002 Havoc Pennington <hp@redhat.com>
- cvs snap 2002-06-11

* Tue May 28 2002 Havoc Pennington <hp@redhat.com>
- rebuild in different environment

* Tue May 28 2002 Havoc Pennington <hp@redhat.com>
- cvs snap 2002-05-24

* Mon Mar 18 2002 Havoc Pennington <hp@redhat.com>
- require new gmp, old ones make it crash for some reason,
  #60857

* Wed Feb 27 2002 Havoc Pennington <hp@redhat.com>
- don't strip libraries
- avoid putting same files in both -devel and plain package

* Sun Oct 28 2001 Havoc Pennington <hp@redhat.com>
- upgrade to 0.15.1

* Wed Aug  8 2001 Jonathan Blandford <jrb@redhat.com>
- We own %{_datadir}/rep and %{_datadir}/libexec/rep.  Fix #51156

* Mon Jul 16 2001 Havoc Pennington <hp@redhat.com>
- BuildPrereq gdbm-devel
- fix TODO in doc file list

* Tue Jun 26 2001 Florian La Roche <Florian.LaRoche@redhat.de>
- add links to library major version number into rpm filelist

* Fri May 11 2001 Bernhard Rosenkraenzer <bero@redhat.com> 0.13.6-2
- Rebuild with new readline

* Mon Apr 30 2001 Jonathan Blandford <jrb@redhat.com>
- Upgrade to 0.13.6

* Tue Dec 5 2000 Havoc Pennington <hp@redhat.com>
- Upgrade to .13.3
- put all files in prefix/libexec/platform/rep/* in the file list

* Fri Aug 11 2000 Jonathan Blandford <jrb@redhat.com>
- Up Epoch and release

* Thu Jul 13 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Sun Jun 18 2000 Matt Wilson <msw@redhat.com>
- 0.12.1
- remove stack smash workaround patch

* Sat Jun 17 2000 Matt Wilson <msw@redhat.com>
- use %%configure and %%makeinstall
- use %%{_infodir}

* Sat Jun  17 2000 Havoc Pennington <hp@redhat.com>
- 0.12
- remove gmp patch to configure.in, seems to have been merged upstream
- remove ia64 hack, since upstream seems to have addressed the issue
  (though it isn't the same solution as our patch, so may or may not 
  work)

* Thu May 18 2000 Bill Nottingham <notting@redhat.com>
- tweaks for ia64

* Fri Apr 28 2000 Matt Wilson <msw@redhat.com>
- rebuilt against gmp 3.0.1

* Sat Apr 22 2000 Bill Nottingham <notting@redhat.com>
- update to 0.11.3

* Mon Apr 10 2000 Bill Nottingham <notting@redhat.com>
- update to 0.11.2

* Mon Apr  3 2000 Bill Nottingham <notting@redhat.com>
- ditto

* Tue Mar 21 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- rebuild with new readline

* Fri Mar 10 2000 Bill Nottingham <notting@redhat.com>
- update to 0.11.1

* Thu Feb  3 2000 Bill Nottingham <notting@redhat.com>
- add install-info stuff

* Mon Jan 10 2000 Bill Nottingham <notting@redhat.com>
- update to 0.10
- don't pacakge ldconfig symlinks

* Thu Nov 11 1999 Michael K. Johnson <johnsonm@redhat.com>
- Remove stack tracing on alpha in order not to trigger internal
  compiler error.  Should be reverted when we get a newer
  compiler; development gcc has this fixed.

* Wed Nov 10 1999 Michael K. Johnson <johnsonm@redhat.com>
- post{,un} use -p

* Mon Sep 13 1999 Aron Griffis <agriffis@bigfoot.com>
- 0.5 spec file update: added buildroot
